==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebCancelableBrowserEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebCancelableBrowserEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableBrowserEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableBrowserEventArgsDetailDescriptionMetadata.a == null) {
                WebCancelableBrowserEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableBrowserEventArgsDetailDescriptionMetadata.c(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CancelableBrowserEventArgsDetail");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebCancelableBrowserEventArgsDetailDescriptionMetadata.b(a);
            a.z("WebCancelableBrowserEventArgsDetail", WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCancelableBrowserEventArgsDetailDescriptionMetadata, 'WebCancelableBrowserEventArgsDetailDescriptionMetadata');
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.a = null;
    return WebCancelableBrowserEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebCancelableBrowserEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebCancelableBrowserEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableBrowserEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableBrowserEventArgsDetailDescriptionMetadata.a == null) {
                WebCancelableBrowserEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableBrowserEventArgsDetailDescriptionMetadata.c(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CancelableBrowserEventArgsDetail");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebCancelableBrowserEventArgsDetailDescriptionMetadata.b(a);
            a.ab("WebCancelableBrowserEventArgsDetail", WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCancelableBrowserEventArgsDetailDescriptionMetadata, 'WebCancelableBrowserEventArgsDetailDescriptionMetadata');
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.a = null;
    return WebCancelableBrowserEventArgsDetailDescriptionMetadata;
})();
